meta_package_manager.bitbar package — Meta Package Manager 2.3.0 documentation

# meta_package_manager.bitbar package

## Submodules

## meta_package_manager.bitbar.meta_package_manager.7h module

## Module contents

Default update cycle is set to 7 hours so we have a chance to get user’s attention once a day. Higher frequency might ruin the system as all checks are quite resource intensive, and Homebrew might hit GitHub’s API calls quota.

`meta_package_manager.bitbar.` `echo`(message)

  Print message to the output.

  Not unlike `click.echo()`, this method is required to support discrepencies in the way strings are handled in different Python versions and platforms.

`meta_package_manager.bitbar.` `fix_environment`()

  Tweak environment variable to find non-default system-wide binaries.

  macOS does not put `/usr/local/bin` or `/opt/local/bin` in the `PATH` for GUI apps. For some package managers this is a problem. Additioanlly Homebrew and Macports are using different pathes. So, to make sure we can always get to the necessary binaries, we overload the path. Current preference order would equate to Homebrew, Macports, then system.

`meta_package_manager.bitbar.` `print_error`(message, submenu=u'')

  Print a formatted error line by line.

  A red, fixed-width font is used to preserve traceback and exception layout.

`meta_package_manager.bitbar.` `print_error_header`()

  Generic header for blockng error.

`meta_package_manager.bitbar.` `print_menu`()

  Print menu structure using BitBar’s plugin API.

  See: https://github.com/matryer/bitbar#plugin-api

`meta_package_manager.bitbar.` `print_package_items`(packages, submenu=u'')

  Print a menu entry for each outdated packages available for upgrade.

`meta_package_manager.bitbar.` `print_upgrade_all_item`(manager, submenu=u'')

  Print the menu entry to upgrade all outdated package of a manager.

`meta_package_manager.bitbar.` `run`(*args)

  Run a shell command, return error code, output and error message.